pub enum AirQualityLevel {
Good,
Moderate,
UnhealthySensitive,
Unhealthy,
VeryUnhealthy,
Hazardous,
}Expand description
Represents the human-friendly interpretation of the AQI
Variants
Good
The air quality is good and safe for everyone
Moderate
The air quality is moderate, but unusually sensitive people should avoid heavy outdoor exertion
UnhealthySensitive
The air quality is unhealthy for those with respiratory issues or other health problems
Unhealthy
The air quality is unhealthy for everyone
VeryUnhealthy
The air quality is very unhealthy for everyone
Hazardous
The air quality is hazardous and everyone should avoid outdoor exertion